"""
Setup script for Mercator Python SDK.

This file is provided for backward compatibility. The package configuration
is primarily defined in pyproject.toml.
"""

from setuptools import setup

# Configuration is in pyproject.toml
setup()
